﻿using System;
using System.Configuration;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WebForms;

namespace Quickstart
{
    public partial class WebForm1 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                GetShapeFile();
            }
        }
        protected void GetShapeFile()
        {
            Map1.MapBackground = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            Map1.MapUnit = GeographyUnit.Meter;

            Map1.MapTools.OverlaySwitcher.Enabled = true;
            Map1.MapTools.MouseCoordinate.Enabled = true;
            var google = new GoogleOverlay("Google Map");
            
            google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
            google.GoogleMapType = GoogleMapType.Normal;

            var shapeFileFeatureLayer = new ShapeFileFeatureLayer(Server.MapPath("~/App_Data/US.shp"));
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, 212, 220, 184), GeoColor.FromArgb(255, 132, 132, 154), 1);
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            ShapeFileFeatureLayer.BuildIndexFile(shapeFileFeatureLayer.ShapePathFilename);

            var proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4269);
            proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
            shapeFileFeatureLayer.FeatureSource.Projection = proj4;

            var shapeOverlay = new LayerOverlay();
            shapeOverlay.Layers.Add("ShapeOverlay", shapeFileFeatureLayer);
            shapeOverlay.TransitionEffect = TransitionEffect.None;
            shapeOverlay.IsBaseOverlay = false;
            shapeOverlay.TileType = TileType.SingleTile;
            Map1.CustomOverlays.Add(google);
            Map1.CustomOverlays.Add(shapeOverlay);
            shapeFileFeatureLayer.Open();
            Map1.CurrentExtent = shapeFileFeatureLayer.GetBoundingBox();
            shapeFileFeatureLayer.Close();
        }
    }
}